@@ -3,7 +3,7 @@ library(stringr)
 library(statar)
 context("is.panel")
 
-df <- data_frame(
+df <- tibble(
     id1    = c(1, 1, 1, 2, 2),
     id2   = 1:5,
     year  = c(1991, 1993, NA, 1992, 1992),
